%MPM_ASbaffledradzmatrix : Modal radiation impedance matrix
%
% Zmat = MPM_ASbaffledradzmatrix(k, rho, c, S, maxmodes, bz)
% 
% Calculates the modal radiation impedance matrix for the 
% end of a circular tube terminated in an infinite baffle
% by interpolation of a lookup table.
%
% The matrix Zmat is a square, symmetrical matrix. 
%
% Input parameters:
% k : wavenumber
% rho : density of medium
% c : sound speed in medium
% S : area of tube opening
% maxmodes : maximum number of modes calculated
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%

function ZmatOut = MPM_ASbaffledradzmatrixIntp(k, rho, c, S, maxmodes)
ZmatOut = zeros(maxmodes, maxmodes, length(k));


load 'ZradA_64.mat';
ka = ka * sqrt(1/pi);
kain = k*sqrt(S/pi);
for i=1:maxmodes
    for j=1:maxmodes
        %disp (['for mode m,n = ' num2str(m) ',' num2str(n)]);
            negexpol = find(kain < min(ka));
            intpol = find((kain >= min(ka)) & (kain <= max(ka)));
            posexpol = find(kain > max(ka));
            Y = squeeze(real(Zmat(i,j,:)));
            R1 = interp1(ka', Y, kain(negexpol)','pchip','extrap');
            R2 = interp1(ka', Y, kain(intpol)','spline','extrap');
            if (i==j)
                R3 = ones(size(kain(posexpol)'));
            else
                R3 = zeros(size(kain(posexpol)'));
            end;
            %R3 = interp1(ka', Y, kain(posexpol)','linear','extrap');
            R = [R1; R2; R3];
            %R = ones(size(kain'));
            Y = squeeze(imag(Zmat(i,j,:)));
            X1 = interp1(ka', Y, kain(negexpol)','linear','extrap');
            X2 = interp1(ka', Y, kain(intpol)','spline','extrap');
            X3 = interp1(ka', Y, kain(posexpol)','linear','extrap');
            X = [X1; X2; X3];
            Zmn = R +1j*X; 
            ZmatOut(i,j,:) = Zmn;
    end;
end;

ZmatOut = rho*c/S*ZmatOut;

