%MPM_ASmakekm : wave number matrix km
% 
% km = MPM_ASmakekm(k,R,bz,M)
% 
% Calculates the modal wave number matrix km.
% 
% Input parameters: 
% k : free space wave number
% R : radius of the tube
% bz : zeros of Bessel function J1
% M : number of modes
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%
function km = MPM_ASmakekm(k,R,bz,M)

gamma_m = bz(1:M);
gmR = (gamma_m./R);
gmRm = gmR(:,ones(1,length(k)));
km = k(ones(M,1),:);
km = sqrt(km.^2-gmRm.^2);
co=find((gmRm>km));
km(co)=-km(co);
