%MPM_GetRectModeIndexing: creates the indexing of rectangular modes
%
% rmi = MPM_GetRectModeIndexing(Nmodes);
% 
% Creates a vector of (m,n) mode pairs for rectangular ducts. The same
% number of modes is assumed in each direction.
%
% input parameter:
% Nmodes : number of modes in each direction
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%


function rmi = MPM_GetRectModeIndexing(Nmodes);

Ntot = Nmodes.^2;
rmi = zeros(Ntot,2);
indx = 1;
for i=0:Nmodes-1
    for j=0:i 
        if j==i
            rmi(indx,:) = [i j];
            indx = indx+1;
        else
            rmi(indx,:) = [j i];
            indx = indx+1;
            rmi(indx,:) = [i j];
            indx = indx+1;
        end;
    end;
end;
    
    