%MPM_RECAbaffledradz : Modal radiation impedance matrix
%
% Z = MPM_RECAbaffledradz(k, rho, c, a, b, n, m)
% 
% Calculates the modal radiation impedance for the 
% end of a rectangular duct terminated in an infinite baffle
% by numerical interation.
% Calculates both symmetrical and asymmetrical modes.
% The fundamental (plane wave) mode impedance is calcualted
% by analytical functions.
%
% Input parameters:
% k : wavenumber
% rho : density of medium
% c : sound speed in medium
% a, b : full width and full height of the duct
% n, m : mode numbers n(1) = n_x, n(2) = n_y etc.
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%

% TEST: prvar  integrere 0-a, 0-b, istaden for 0-ka, 0-kb

function [Z, t] = MPM_RECAbaffledradz_test(k, rho, c, a, b, n, m)
%Zmat = zeros(maxmodes, maxmodes, length(k));
ka = k*a;
kb = k*b;
S = a*b;
nx = n(1);
ny = n(2);
mx = m(1);
my = m(2);
Z = k;
t = k;
f = ffunc(nx,ny,mx,my)
for ii=1:length(k)
    t01 = tic;
    kk = k(ii);
    %adaptive accuracy
    eps = 10.^(-log(2.5*kk*min(a,b))-1);
    eps = max(min(0.01,eps),1e-6);
%     eps = 1e-8;
    ka = kk*a;
    kb = kk*b;
    %disp(sprintf('Asymmetric radiation Z for mode (%d,%d),(%d,%d) at k=%f\n',nx,ny,mx,my,kk));
%     Z0 = 0;%dblquad(@(x,y) Integrand0(x,y,ka,kb,f),0,ka,0,kb,eps, @myquad);%
    Z1 = dblquad(@(x,y) Integrand1(x,y,kk,a,b,nx,ny,mx,my,f), 0,a,0,b, eps, @myquad);%
%     Z2 = quadl(@(x) Integrand2(x,ka,kb,nx,ny,mx,my,f),0,ka,eps);
%    Z2 = quadv(@(x) Integrand2(x,ka,kb,nx,ny,mx,my),0,ka,eps);
    Z(ii) = Z1; %-Z0+Z2;
    t(ii) = toc(t01);
end;
%Z2 = quadv(@(x) Integrand2(x,2*k*a,2*k*b,nx,ny,mx,my),0,2*k*a,eps);
% Z3 = (-0.75*k.*a.*log(k*a)+0.875*k*a).*f;
Z = 1i*rho*k/(2*pi*S).*Z; %(Z+Z3);
%Zmat = rho*c/S*Zmat;

function I0 = Integrand0(x,y,ka,kb,f)
onem1 = (1-0.5*x/ka);
onem2 = (1-0.5*y/kb);
rt = sqrt(x.^2+y.^2);
I0 = -f*onem1.*onem2./rt;


function I1 = Integrand1(x,y,k,a,b,nx,ny,mx,my,f)
ka = k*a;
kb = k*b;
% onem1 = (1-0.5*x/ka);
% onem2 = (1-0.5*y/kb);
h = sqrt(x.^2+y.^2);
Gf =Gfunc(nx,mx,x,a).*Gfunc(ny,my,y,b); 
%Gf = Gf./((1-x./(2*ka)).*(1-y./(2*kb)));
I1 = (exp(-1i*k*h).*Gf)./h; % - onem1.*onem2./rt*f; % f part can be omitted when f = 0 onem1.*onem2.*

function I2 = Integrand2(x,ka,kb,nx,ny,mx,my,f)
rt = sqrt(x.^2+kb.^2);
I2 = (1-0.5*x./ka).*(log(kb+rt)+ (x-rt)*0.5/kb).*f;

function G = Gfunc(nx, mx, ksi, a)
if (nx==0)&(mx==0)
    G = 2*(a-ksi);
else
% sinc(x) = sin(pi*x)/(pi*x), so skip multiplying by pi.
    sa1 = (nx+mx)*(1-ksi/(2*a));
    sa1b = (nx-mx)*ksi/(2*a);
    ca1 = sa1b*pi;
    sa2 = (nx-mx)*(1-ksi/(2*a));
    sa2b = (nx+mx)*ksi/(2*a);
    ca2 = sa2b*pi;

    G = cos(ca1).*0.5.*((2*a-ksi).*sinc(sa1)-ksi.*sinc(sa2b)) ...
       + cos(ca2).*0.5.*((2*a-ksi).*sinc(sa2)-ksi.*sinc(sa1b));

    G = Nnx(nx)*Nnx(mx).*G; % ./ (1-0.5*ksi);
end;

function f = ffunc(nx, ny, mx, my)
% sinc(x) = sin(pi*x)/(pi*x), so skip multiplying by pi.
% f is only != 0 when nx == mx && ny == my
f = Nnx(nx)*Nnx(mx)*Nnx(ny)*Nnx(my)*(sinc((nx+mx)) + sinc((nx-mx))) * (sinc((ny+my)) + sinc((ny-my)));

function N = Nnx(nx)
if (nx==0)
    N = 1;
else
    N = sqrt(2);
end;

function q = myquad(f,a,b,tol,trace,varargin)
q = quadgk(@(x)f(x,varargin{:}),a,b,'RelTol',tol);


