%MPM_RECbaffledradz : Modal radiation impedance matrix
%
% Z = MPM_RECbaffledradz(k, rho, c, a, b, n, m)
% 
% Calculates the modal radiation impedance for the 
% end of a rectangular duct terminated in an infinite baffle
% by numerical interation.
% Calculates ONLY symmetrical modes.
% The fundamental (plane wave) mode impedance is calcualted
% by analytical functions.
%
% Input parameters:
% k : wavenumber
% rho : density of medium
% c : sound speed in medium
% a, b : half width and half height of the duct
% n, m : mode numbers n(1) = n_x, n(2) = n_y etc.
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%

function [Z, t] = MPM_RECbaffledradz_test(k, rho, c, a, b, n, m)
%Zmat = zeros(maxmodes, maxmodes, length(k));
ka = k*a;
kb = k*b;
S = 4*a*b;
R = sqrt(S/pi);
nx = n(1);
ny = n(2);
mx = m(1);
my = m(2);
% if length(k) > 1 
    eps = 1e-4;
% end;
Z = k;
t = k;
f = ffunc(nx,ny,mx,my);
for ii=1:length(k)
    t01 = tic;
    kk = k(ii);
    eps = 10.^(-log(5*kk*min(a,b))-1);
    eps = max(min(0.01,eps),1e-6);
%     eps = 1e-6;
    ka = 2*kk*a;
    kb = 2*kk*b;
    %disp(sprintf('Symmetric radiation Z for mode (%d,%d),(%d,%d) at k=%f\n',nx,ny,mx,my,kk));
    Z1 = dblquad(@(x,y) Integrand1(x,y,ka,kb,nx,ny,mx,my,f), 0,ka,0,kb, eps, @myquad);%
    Z2 = quadl(@(x) Integrand2(x,ka,kb,nx,ny,mx,my,f),0,ka,eps);
%    Z2 = quadv(@(x) Integrand2(x,ka,kb,nx,ny,mx,my),0,ka,eps);
    Z(ii) = Z1+Z2;
    t(ii) = toc(t01);
end;
%Z2 = quadv(@(x) Integrand2(x,2*k*a,2*k*b,nx,ny,mx,my),0,2*k*a,eps);
Z3 = (-k.*a.*log(2*k*a)+1.5*k*a).*f;
Z = 1i*rho*c/(2*pi*S)*(Z+Z3);

%Zmat = rho*c/S*Zmat;

function f = ffunc(nx, ny, mx, my)
% sinc(x) = sin(pi*x)/(pi*x), so skip multiplying by pi.
f = Nnx(nx)*Nnx(mx)*Nnx(ny)*Nnx(my)*(sinc((nx+mx)) + sinc((nx-mx))) * (sinc((ny+my)) + sinc((ny-my)));

function N = Nnx(nx)
if (nx==0)
    N = 1;
else
    N = sqrt(2);
end;

function G = Gfunc(nx, mx, ksi, a)
if (ksi==1)
    ksi = 0.999999999;
end;
if (nx==0)&(mx==0)
    G = 2*(2*a-ksi)./(1-ksi);
else
    % sinc(x) = sin(pi*x)/(pi*x), so skip multiplying by pi.
    sa1 = (nx+mx)*(1-ksi/(2*a));
    ca1 = (nx-mx)*pi*ksi/(2*a);
    sa2 = (nx-mx)*(1-ksi/(2*a));
    ca2 = (nx+mx)*pi*ksi/(2*a);
    G = (2*a-ksi).*( sinc(sa1).*cos(ca1) + sinc(sa2).*cos(ca2)) ./ (1-ksi);
    G = Nnx(nx)*Nnx(mx).*G;
end;

function I1 = Integrand1(x,y,ka,kb,nx,ny,mx,my,f)
onem1 = (1-x/ka);
onem2 = (1-y/kb);
rt = sqrt(x.^2+y.^2);
Gf =Gfunc(nx,mx,x/ka,0.5).*Gfunc(ny,my,y/kb,0.5); 
%Gf = Gf./((1-x./(ka)).*(1-y./(kb)));
I1 = onem1.*onem2./rt.*(exp(-1i*rt).*Gf-f);

function I2 = Integrand2(x,ka,kb,nx,ny,mx,my,f)
rt = sqrt(x.^2+(kb).^2);
I2 = (1-x./ka).*(log(kb+rt)+ (x-rt)/kb).*f;


function q = myquad(f,a,b,tol,trace,varargin)
q = quadgk(@(x)f(x,varargin{:}),a,b,'RelTol',tol);
