%MPM_ASbaffledradzmatrixIntp : Modal radiation impedance matrix
%
% Zmat = MPM_ASbaffledradzmatrixIntp(k, rho, c, S, maxmodes, bz)
% 
% Calcualtes the modal radiation impedance matrix for the 
% end of a rectangular tube terminated in an infinite baffle
% by interpolation of a lookup table.
% The fundamental (plane wave) mode impedance is calcualted
% by analytical functions.
%
% The matrix Zmat is a square, symmetrical matrix. 
%
% Input parameters:
% k : wavenumber
% rho : density of medium
% c : sound speed in medium
% a : half width of opening
% b : half height of opening
% Nmodes : number of modes calculated in each direction
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%

function ZmatOut = MPM_RECbaffledradzmatrixIntp(k, rho, c, a, b, Nmodes)

% freq = logspace(log10(1), log10(20000), 200);
% k = logspace(log10(0.01), log10(30), 200);% 2*pi*freq/c;
% 
% a = 1;
% b = 1;
% c = 1;
% rho = 1;
% Nmodes = 2;


kain = k*a;
modeindex = MPM_GetRectModeIndexing(Nmodes);
N = size(modeindex,1);
ZmatOut = zeros(N, N, length(k));

if abs(a/b-1)<0.1
    load ZmatRecSq16x16.mat;
    L = length(Zmat(:,1,1));
    if L < N
        error(sprintf('to many modes! Current: %d, Requested: %d', L, N));
        return;
    end;
    L = length(k);
    for i=1:N%n
        for j=1:N%m
            negexpol = find(kain < min(ka));
            intpol = find((kain >= min(ka)) & (kain <= max(ka)));
            posexpol = find(kain > max(ka));
            Y = squeeze(real(Zmat(i,j,:)));
            R1 = interp1(ka', Y, kain(negexpol)','pchip','extrap');
            R2 = interp1(ka', Y, kain(intpol)','spline','extrap');
            if (i==j)
                R3 = 0.25*ones(size(kain(posexpol)'));
            else
                R3 = zeros(size(kain(posexpol)'));
            end;
            %R3 = interp1(ka', Y, kain(posexpol)','linear','extrap');
            R = [R1; R2; R3];
            %R = ones(size(kain'));
            Y = squeeze(imag(Zmat(i,j,:)));
            X1 = interp1(ka', Y, kain(negexpol)','linear','extrap');
            X2 = interp1(ka', Y, kain(intpol)','spline','extrap');
            X3 = interp1(ka', Y, kain(posexpol)','linear','extrap');
            X = [X1; X2; X3];
            Zmn = R +1j*X; 
            ZmatOut(i,j,:) = Zmn;
        end;
    end;        
else
    disp(sprintf('Aspect ratio: %.10f',a/b));
    error('No tabulated values for this aspect ratio!');  
end;

ZmatOut = rho*c/(a*b)*ZmatOut; % the 4 in S (S=4*a*b) is already accounted for

clear Zmat;

% figure(1);
% Z = squeeze(ZmatOut(1,1,:));
% Z2 = squeeze(ZmatOut(2,3,:));
% semilogx(kain, real(Z), 'k', kain, imag(Z),'r', kain, real(Z2), 'b', kain, imag(Z2),'m');
