%MPM_RECmakekm : wave number matrix km
% 
% kn = MPM_RECmakekm(k,a,b,M,ModeIndices)
% 
% Calculates the modal wave number matrix km.
% 
% Input parameters: 
% k : free space wave number
% a : half width of the duct
% b : half height of the duct
% M : number of modes in each direction
% ModeIndices : sorted index of modes
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%
function kn = MPM_RECmakekm(k,a,b,M,ModeIndices)
alpha2 = (ModeIndices(:,1)*pi/a).^2+(ModeIndices(:,2)*pi/b).^2;
alpha2m = alpha2(:,ones(1,length(k)));
kn = k(ones(M^2,1),:);
co=find(alpha2m>kn.^2);
kn = sqrt(kn.^2-alpha2m);
kn(co)=-kn(co);

