%MPM_gethorntype(htype)
% 
% hornname = MPM_gethorntype(htype)
% 
% Returns a string with the type of the horn.
% 
% Input parameters: 
% htype : horn type. The following horn types are supported:
%   0 : conical horn
%   1 : exponential horn
%   2 : hyperbolic-exponential (hypex) horn (Salmon type horn)
%   3 : Oblate Spheroidal Waveguide
%   4 : Bessel horn
%   5 : Spherical wave horn
%   6 : Tractrix horn
%   7 : Radius
%
% See also: MPM_AShorncoord
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%
function hornname = MPM_gethorntype(htype)
if htype == 0 
    hornname = 'Conical';
elseif htype == 1
    hornname = 'Exponential';
elseif htype == 2
    hornname = 'Hypex';
elseif htype == 3
    hornname = 'OSWG';
elseif htype == 4
    hornname = 'Bessel';
elseif htype == 5
    hornname = 'Spherical';
elseif htype == 6
    hornname = 'Tractrix';
elseif htype == 7
    hornname = 'Radius';
else
    hornname = 'Unsupported horn type';
end;
%   0 : conical horn
%   1 : exponential horn
%   2 : hyperbolic-exponential (hypex) horn (Salmon type horn)
%   3 : Oblate Spheroidal Waveguide
%   4 : Bessel horn, S = S0 * x^n
%   7 : Radius: the horn profile is part of a circle or radius RadR, starting at an angle
%       thFta, and ending at an angle RadFta (Fta = flare tangent angle)    