%MPM_refinecoords(coords, newdz)
% 
% newcoords = MPM_refinecoords(coords, newdz)
% 
% Given a list of coordinates, subdivides and interpolates the list so that
% no segment is longer than newdz.
%
% Input parameters: 
% coords: list of coordinates. First coordinate must be the z coordinate.
% newdz : maximum length of any segment.
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%
function newcoords = MPM_refinecoords(coords, newdz)
s = size(coords);
N = s(1);
newcoords = [];
for ih = 1:N-1
    dL = coords(ih+1,1)-coords(ih,1);
    if (dL>newdz) 
        Nn = ceil(dL/newdz);
        part = ones(Nn, s(2));
        part(:,1) = linspace(coords(ih,1), coords(ih+1,1), Nn);
        if ((ih>1))
            dL1 = coords(ih,1) - coords(ih-1,1);
            if (dL1>newdz)
                x = [coords(ih-1,1); coords(ih,1); coords(ih+1,1)];
                Y = [coords(ih-1,2:end); coords(ih,2:end); coords(ih+1,2:end)]; 
            else
                x = [coords(ih,1); coords(ih+1,1)];
                Y = [coords(ih,2:end); coords(ih+1,2:end)];
            end;
        else
            x = [coords(ih,1); coords(ih+1,1)];
            Y = [coords(ih,2:end); coords(ih+1,2:end)];
        end;
        xi = part(:,1);
        yi = interp1(x,Y,xi,'spline');
        part(:,2:end)= yi;%coords(ih,2:end);
        newcoords = [newcoords; part(1:end-1,:)];
    else
        newcoords = [newcoords;coords(ih,:)];
    end;
end;
newcoords = [newcoords;coords(N,:)];
        
        