%struveH1 : Struve function of order 1.
% 
% st=struveH1(X)
% 
% Calculates the Struve function of order 1 by series expansion
% for X <= 20, and by polynomial approximation for X < 20.
%
%
function st=struveH1(X)

  st=X;
  for ii=1:length(X)
      R = 1.0;
      x=X(ii);
      if (x <= 20) 
        S = 0;
        A0 = -2.0/pi;
        for K=1 : 60 
          R = -R*x*x/(4.0*K*K-1.0);
          S = S+R;
          if  (abs(R) < abs(S)*1E-12)  
              break;
          end;
        end;
        st(ii) = A0 * S;
      else
        S = 1.0;
        KM = round(0.5*x);
        if (x > 50)  KM = 25; end;
        for K = 1 : KM 
          R = -R*(4*K*K-1)/(x.*x);
          S = S+R;
          if (abs(R) < abs(S)*1E-12)  break; end;
        end;
        T = 4.0./x;
        T2 = T*T;
        P1 = ((((0.42414E-5*T2-0.20092E-4)*T2+0.580759E-4)...
         *T2-0.223203E-3)*T2+0.29218256E-2)*T2+0.3989422819E0;
        Q1 = T*(((((-0.36594E-5*T2+0.1622E-4)*T2-0.398708E-4)...
         *T2+0.1064741E-3)*T2-0.63904E-3)*T2+0.0374008364E0);
        TA1 = x-0.75*pi;
        BY1 = 2.0/sqrt(x)*(P1*sin(TA1)+Q1*cos(TA1));
        st(ii) = 2.0/pi*(1.0+S/(x.*x))+BY1;
      end;
  end;
