%MPM_ASbaffledradzmatrix : Modal radiation impedance matrix
%
% Zmat = MPM_ASbaffledradzmatrix(k, rho, c, S, maxmodes, bz)
% 
% Calcualtes the modal radiation impedance matrix for the 
% end of a circular tube terminated in an infinite baffle
% by numerical interation.
% The fundamental (plane wave) mode impedance is calcualted
% by analytical functions.
%
% The matrix Zmat is a square, symmetrical matrix. 
%
% Input parameters:
% k : wavenumber
% rho : density of medium
% c : sound speed in medium
% S : area of tube opening
% maxmodes : maximum number of modes calculated
% bz : zeros of Bessel function J1
%
%  --------------------------------------------------- -------------------------------------------
%    This file is part of the Modal Propagation Method (MPM) Toolbox by Bjrn Kolbrek.                       
%                                                                                               
%    The MPM Toolbox is free software: you can redistribute it and/or modify       
%    it under the terms of the GNU General Public License as published by the Free Software     
%    Foundation, either version 3 of the License, or (at your option) any later version.        
%                                                                                                
%    The MPM Toolbox is distributed in the hope that it will be useful,       
%    but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS  
%    FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.             
%                                                                                                
%    You should have received a copy of the GNU General Public License along with the           
%    MPM Toolbox. If not, see <http://www.gnu.org/licenses/>.                 
%  --------------------------------------------------- -------------------------------------------
%

function Zmat = MPM_RECbaffledradzmatrix(k, rho, c, a, b, Nmodes)

modeindex = MPM_GetRectModeIndexing(Nmodes);
N = size(modeindex,1);
Zmat = zeros(N, N, length(k));
for i=1:N%n
    for j=1:N%m
        if j >= i
            Zmn = MPM_RECbaffledradz(k, rho, c, a, b, modeindex(i,:), modeindex(j,:));
        else
            Zmn = Zmat(j,i,:); % exploiting symmetry if the matrix
        end;
        Zmat(i,j,:) = Zmn;
    end;
end;